.. _examples-index:

Basics Gallery with Matplotlib
==============================

This page consists of the 'Basics Gallery with matplotlib' and a sub-gallery
(aka subsection), 'No image output examples'. This sub-gallery is generated from a
sub-directory within the general examples directory. The file structure of
this gallery looks like this:

.. code-block:: none

    examples/           # base 'Basics Gallery with Matplotlib' directory
    ├── GALLERY_HEADER.rst
    ├── <.py files>
    └── no_output/      # generates the 'No image output examples' sub-gallery
        ├── GALLERY_HEADER.rst
        └── <.py files>

.. _general_examples:

General examples
----------------

This gallery consists of introductory examples and examples demonstrating
specific features of Sphinx-Gallery.
